//Plastic part to connect 2 3/4" EMT Pipes at 60 degs. to each other
//By: David Bunch 10/24/2015
//Ht = 37.7;
Ht = 41.7;
Ht_2 = Ht / 2;
EMT_OD=23.7;
EMT_Res = 106;
M3 = 3.4;
$fn=24;
M3_ires=24;
M3NutDia=9.18;

M3Nut_Ht=4.7;
RotNut=0;
module PipeConnect()
{
    translate([0,0,-Ht_2])
    union()
    {
        linear_extrude(height = Ht, center = false, convexity = 10)polygon(points = 
    [[-12.04,-16.85],[-11.4,-17.68],[-10.57,-18.31],[-9.61,-18.71],[-8.57,-18.85],
    [44.02,-18.85],[44.81,-18.77],[45.56,-18.55],[46.25,-18.18],[46.85,-17.68],
    [47.35,-17.07],[47.72,-16.38],[47.95,-15.63],[48.02,-14.85],[48.02,14.85],
    [47.95,15.63],[47.72,16.38],[47.35,17.07],[46.85,17.68],[46.25,18.18],
    [45.56,18.55],[44.81,18.77],[44.02,18.85],[8.72,18.85],[8.03,18.79],
    [7.35,18.61],[6.72,18.31],[-19.11,3.4],[-19.75,2.94],[-20.28,2.37],
    [-20.7,1.71],[-20.97,0.97],[-21.1,0.2],[-21.08,-0.59],[-20.9,-1.35],
    [-20.57,-2.06]]);
        EMT_Nuts2();
        EMT_NutsSide();
    }
}
module EMT_Nut()
{
    rotate([0,-90,0])
    difference()
    {
        linear_extrude(height = 6, center = false, convexity = 10)polygon(points = 
        [[8.23,-1.74],[8.23,1.74],[8.19,2.13],[8.08,2.51],[7.89,2.86],
        [7.64,3.16],[0,10.8],[-0.86,10.8],[-0.86,-10.8],[0,-10.8],
        [7.64,-3.16],[7.89,-2.86],[8.08,-2.51],[8.19,-2.13]]);
        translate([4.1,0,-1])
        cylinder(d=M3,h=8,$fn=24);
    }
}
module EMT_Nuts2()
{
    translate([1.1335,-3.9633,Ht])
    rotate([0,0,30])
    EMT_Nut();

    translate([8.0617,0.0367,Ht])
    rotate([0,0,30])
    EMT_Nut();
}
module EMT_NutsSide()
{
    translate([23.0248+11,-7.0000,Ht])
    rotate([0,0,-90])
    EMT_Nut();
    translate([23.0248+11,1.0000,Ht])
    rotate([0,0,-90])
    EMT_Nut();
}
module PipeSlots()
{
    translate([-7.6160,11.1913,0])
    rotate([0,0,-60])
    cube([37,2,EMT_OD]);

    translate([23.02,-1,0])
    cube([26,2,EMT_OD]);
}
module Pipe1x()
{
    color("Silver")
    {
        translate([-48.1681,6.8450,0])
        rotate([0,0,30])
        rotate([-90,0,0])

        cylinder(d=EMT_OD,h=300,$fn=64);            //Cut Left Side opening for EMT pipe
        translate([48.1681,6.8450,0])
        rotate([0,0,-30])
        rotate([-90,0,0])
        cylinder(d=EMT_OD,h=300,$fn=64);
    }
}
module Pipes()
{
    translate([0,0,0])
    rotate([0,0,30])
    rotate([90,0,0])
    translate([0,0,-100])
    cylinder(d=EMT_OD,h=200,$fn=64);
    translate([23.02,0,0])
    rotate([0,90,0])
    cylinder(d=EMT_OD,h=100,$fn=EMT_Res);
}


module NutTrap()
{
//Drill the Right Bolt Hole
        translate([0,0,-(Ht_2+1)])
        cylinder(d=M3,h=12,$fn=M3_ires);
//Cut Right Nut Trap
        translate([0,0,-(Ht_2-4)])
        rotate([0,0,RotNut])            //Rotate Nut either 0 or 30
        cylinder(d=M3NutDia,h=M3Nut_Ht+1,$fn=6);        //6 sided Nut trap hole

}
module DrawFinal()
{
    difference()
    {
        PipeConnect();
        Pipes();

        PipeSlots();

        NutTrap();                  //Bottom of Main Pipe
        translate([36,0,0])
        NutTrap();                  //Bottom of Side Pipe
        rotate([90,0,0])
        translate([36,0,0])
        NutTrap();                  //Side of Side Pipe
//Cut Nut Trap in the Front
        rotate([0,0,30])
        rotate([0,90,0])
        rotate([0,0,30])
        NutTrap();                  //Front of Printer

        ChamferBot();  
        mirror([0,1,0])
        rotate([180,0,0])
        ChamferBot();      
    }
}
module ChamferBot()
{
    translate([-12,18.85-2,-(Ht_2-2)])
    BotChamCyl();
    translate([50,-16.85,-(Ht_2-2)])
    rotate([0,0,180])
    BotChamCyl();
    translate([48,19.85,-(Ht_2-2)])
    rotate([0,0,-90])
    BotChamCyl();
    translate([-7.34,-20.98,-(Ht_2-2)])
    rotate([0,0,120])
    BotChamCyl();
    translate([-21.57,-0.33,-(Ht_2-2)])
    rotate([0,0,30])
    BotChamCyl();
}
module BotChamCyl()
{
rotate([0,90,0])
difference()
{
    cylinder(d=8,h=70);
    translate([0,0,-1])
    cylinder(d=4,h=72);
    translate([-10,-5,-1])
    cube([10,10,72]);
    translate([-5,-10,-1])
    cube([10,10,72]);
}
}
module VertChamfers()
{
    translate([-11.3313,-19.6265,-(Ht_2+1)])
    rotate([0,0,15])
    cylinder(d=6,h=Ht+2,$fn=4);         //Bottom Left Chamfer
    
    translate([-22.57,1.4,-(Ht_2+1)])
    rotate([0,0,30])
    cylinder(d=6,h=Ht+2,$fn=4);         //Top Left Chamfer
    
    translate([7.3534,20.2857,-(Ht_2+1)])
    rotate([0,0,-32.37])
    cylinder(d=6,h=Ht+2,$fn=4);         //Top Middle Chamfer
    
    translate([48.02,18.85,-(Ht_2+1)])
    rotate([0,0,0])
    cylinder(d=6,h=Ht+2,$fn=4);         //Top Right Chamfer
    
    translate([48.02,-18.85,-(Ht_2+1)])
    rotate([0,0,0])
    cylinder(d=6,h=Ht+2,$fn=4);         //Bottom Right Chamfer
}
DrawFinal();
%Pipes();
translate([25.45,44,0])
mirror([1,0,0])
DrawFinal();