//Plastic part to connect 2 3/4" EMT Pipes at 60 degs. to each other
//By: David Bunch 10/24/2015

Pipe_Spacing = 45.5;     //gives 6mm clearance top & bottom of 86mm high vertex
                        //We Need 45mm to put Pipe Tensioning mount in vertically
Pipe_SpaceHalf = Pipe_Spacing / 2;

EMT_OD=23.7;
EMT_Res = 106;
M3 = 3.4;
$fn=24;
M3_ires=24;

M3NutDia=7;
M3Nut_Ht=4.7;
RotNut=30;
Len = 37.7;               //Length of Round Box
Wid = 37.7;               //Width of Round Box
Ht = 25;                //Height of Round Box
Dia = 4;                //Diameter of Rounded Edges
CorRes = 24;            //Resolution of Rounds
RotAng = 360 / (CorRes * 2);
echo("RotAng = ",RotAng);
Rad = Dia / 2;
L2 = Len - Dia;
W2 = Wid - Dia;
H2 = Ht - Dia;
TotWid = 37.7;
Len_Half = Len / 2;
Wid_Half = Wid /2;

TotHt = Ht;
Ht_2 = TotHt / 2;
//Draw Spheres at 4 corners
module SphereCorners()
{
    translate([Rad,Rad,Rad])
    sphere(d=Dia,$fn=CorRes);
    translate([Len-Rad,Rad,Rad])
    sphere(d=Dia,$fn=CorRes);
    translate([Rad,Wid-Rad,Rad])
    sphere(d=Dia,$fn=CorRes);
    translate([Len-Rad,Wid-Rad,Rad])
    sphere(d=Dia,$fn=CorRes);
}
module CylCorner()
{
    translate([Rad,Rad,Rad])

    rotate([0,90,0])
    rotate([0,0,RotAng])                //Rotate to match Sphere Resolution
    cylinder(d=Dia,h=L2,$fn=CorRes);
    translate([Rad,Rad,Rad])
    rotate([-90,0,0])
    rotate([0,0,RotAng])                //Rotate to match Sphere Resolution
    cylinder(d=Dia,h=W2,$fn=CorRes);
}
module RoundTopAndBottom()
{
    CylCorner();
    translate([Len,Wid,0])
    rotate([0,0,180])
    CylCorner();
    SphereCorners();
}
module RoundOutline()
{
    RoundTopAndBottom();            //Draw the Round Bottom Outline
    translate([0,0,Ht-Dia])
    RoundTopAndBottom();            //Draw the Round Top Outline
//Draw the Vertical Cylinders
    translate([Rad,Rad,Rad])
    cylinder(d=Dia,h=H2,$fn=CorRes);
    translate([Len-Rad,Rad,Rad])
    cylinder(d=Dia,h=H2,$fn=CorRes);
    translate([Rad,Wid-Rad,Rad])
    cylinder(d=Dia,h=H2,$fn=CorRes);
    translate([Len-Rad,Wid-Rad,Rad])
    cylinder(d=Dia,h=H2,$fn=CorRes);
}
module DrawRoundBox()
{
    RoundOutline();
    translate([Rad,0,Rad])
    cube([L2,Wid,H2]);
    translate([0,Rad,Rad])
    cube([Rad+.01,W2,H2]);              //Draw the Left Side
    translate([Len-Rad-.01,Rad,Rad])
    cube([Rad+.01,W2,H2]);              //Draw the Right Side
    translate([Rad,Rad,0])
    cube([L2,W2,Rad+.01]);              //Draw the Bottom Side
    translate([Rad,Rad,Ht-Rad-.01])
    cube([L2,W2,Rad+.01]);              //Draw the Top Side
}
module EMT_Nut()
{
    translate([-1,TotWid/2,Ht_2])
    rotate([-90,0,0])
    rotate([0,-90,0])
    difference()
    {
        linear_extrude(height = 6, center = false, convexity = 10)polygon(points = 
        [[8.23,-1.74],[8.23,1.74],[8.19,2.13],[8.08,2.51],[7.89,2.86],
        [7.64,3.16],[0,10.8],[-0.86,10.8],[-0.86,-10.8],[0,-10.8],
        [7.64,-3.16],[7.89,-2.86],[8.08,-2.51],[8.19,-2.13]]);
        translate([4.1,0,-1])
        cylinder(d=M3,h=8,$fn=24);
    }
}
module EMT_NutsSide()
{
    EMT_Nut();
    translate([8,0,0])
    EMT_Nut();
}
module PipeSlots()
{
    translate([-1,-1,-1])
    cube([2,EMT_OD,Ht+20]);
}
module Pipes()
{
    translate([0,0,-1])
    cylinder(d=EMT_OD,h=100,$fn=EMT_Res);
}
module NutTrap()
{
    translate([0,-(12.45),Ht_2])
    rotate([-90,0,0])
    {
//Drill the Right Bolt Hole
        translate([0,0,-(Ht_2+1)])
        cylinder(d=M3,h=12,$fn=M3_ires);
//Cut Right Nut Trap
        translate([0,0,-4])
        rotate([0,0,RotNut])            //Rotate Nut either 0 or 30
        cylinder(d=M3NutDia,h=M3Nut_Ht+1,$fn=6);        //6 sided Nut trap hole
    }
}
module CubeHole()
{
    translate([0,0,-1])
    linear_extrude(height = TotHt+2, center = false, convexity = 10)polygon(points = 
    [[16.85,-11.85],[18.85,-13.85],[26.65,-13.85],
    [28.65,-11.85],[28.65,11.85],[26.65,13.85],
    [18.85,13.85],[16.85,11.85]]);
}

module DrawFinal()
{

    difference()
    {
        union()
        {
            translate([-Len_Half,-Wid_Half,0])
            DrawRoundBox();
            EMT_NutsSide();
        }
        Pipes();

        PipeSlots();
        NutTrap();
        rotate([0,0,-90])
        NutTrap();
        rotate([0,0,90])
        NutTrap();
    }
}
DrawFinal();