//Visual Calculator for Delta-Emmett using 2060 extrusions
//Based on mini Kossel visual calculator located here:
//https://github.com/Jaydmdigital/mk_visual_calc
//
//Remixed on 10/6/2015 by David Bunch
//I translated the calculated geometry from this to Draftsight so I could visually do the 2d calcs.
//
//Found an OpenSCAD Delta-Siulator here: https://github.com/PRouzeau/OpenSCAD-Delta-Simulator
//
//These 3 variables used to show the complete part in the View Area (Comment out if you do not want these)
$vpt=[-70,324,462];
$vpr =[55,0,25];
$vpd =3800;

//========================================================
Frame_Ext_Len = 500;    //Length of Horizontal Aluminum extrusions
Frame_Ext_Ht = 1000 + 12;    //length of extrusions for towers, need cut length
Frame_Ext_Wid = 20;     //Width of extrusions
EMT_OD = 24;            //Outer Dia. of Electrical Conduit Pipe if used
EMT_ID = 21;            //Inner Dia. of Electrical Conduit Pipe if used
EMT_Rad = EMT_OD / 2;

Delta_Ang_1st = 30.77;  //Angle to use for Arms for Calculating Initial Arm Length
//40.394 will give me 288mm arms on a 375mm Width with 2040 extrusions & build height of 25"
//Instead of 21.3" with 30.77 angle & 364mm arms
Rod_Rad = 6/2;          //6mm carbon fiber rods? Just for show anyways

//Vertex Heights (normally 20 for 2020, 40 for 2040, 60 for 2060 & 80 for 2080)
//Original Vertex part for this project measures 41mm in height
Frame_Motor_Ht = 67;    //height of motor from vertex (Change to 40 or 41 for 2040, 80 for 2080, etc)
Frame_Top_Ht = 34;      //Height of Top Vertices (Change to 40 or 41 for 2040, 80 for 2080, etc)
Alum_BaseThk = 0;      //Thickness of Base below 1st extrusion (Will Decrease Build Height)


//****These 14 variables are for 1x 2040 Bottom, Top Horizontal & Vertical extrusionsf
Alum_BaseHorWid = 40;       //Size of Extrusions to use for Base
Alum_BaseHor_Z = 30;        //10 for 2020, 30 for 2040, 50 for 2060 & 70 for 2080
Alum_BaseGap = 0;           //Gap between extrusions
Alum_BaseQty = 1;           //How many Extrusions on Base
Alum_TopHorWid = 40;        //Size of Extrusions to use for Top
Alum_TopHor_Z = 30;         //10 for 2020, 30 for 2040, 50 for 2060 & 70 for 2080
Alum_TopGap = 0;            //Gap between extrusions
Alum_TopQty = 1;            //How many Extrusions at Top
Printer_Xadd = 54.34;       //2040 Vertical For Calculating X overall dimension of Printer
Alum_VertWid = 60;          //use 20, 40, 60 or 80 for Vertical Extrusions
Alum_VertGap = 0;           //Gap between Top extrusions (only used when Alum_TopQty = 2)
Alum_VertQty = 1;           //How many vertical Extrusions at each Vertex
Vertex_X_offset = 25.98;    //X Offset from end of 2040 Alum. Horizontal to Center of Vertical
Vertex_Y_offset = 25.0;     //Y Offset from end of 2040 Alum. Horizontal to Center of Vertical

//***These are used for Electrical Conduit Pipe
Alum_BaseHorWid = 24;       //Size of EMT pipe, it is actually around 23.5mm OD
Alum_BaseHor_Z = 14.85;      //Center of Pipe
Alum_EMT_2X_Z = Alum_BaseHor_Z + 40;
echo("Alum_EMT_2X_Z = ",Alum_EMT_2X_Z);
//Pipe_Spacing = 30+6+2+2;
Alum_BaseGap = 12;          //Gap between Bottom extrusions (only used when Alum_BaseQty = 2)
Alum_BaseQty = 2;           //How many Extrusions on Base
Alum_TopHorWid = 24;        //Size of Extrusions to use for Top
Alum_TopHor_Z = 12;         //10 for 2020, 30 for 2040, 50 for 2060 & 70 for 2080
Alum_TopGap = 0;            //Gap between extrusions
Alum_TopQty = 1;            //How many Extrusions at Top
Alum_VertWid = 24;          //use 20, 40, 60 or 80 for Vertical Extrusions
Vertex_X_offset = 31.01;    //X Offset from end of 2060 Alum. Horizontal to Center of Vertical
Vertex_Y_offset = 36.1;    //Y Offset from end of 2060 Alum. Horizontal to Center of Vertical

Printer_Xadd = 64.4;        //2060 Vertical For Calculating X overall dimension of Printer
//****
Glass_Z_Offset = 13.7;     //Offset of Glass above Frame
Glass_Thk = 3;          //Glass Thickness
Eff_Ht = 11;            //Thicknes of Effector

HotEnd_Ht = 45;         //Height of Hotend

//========================================================
Zrot = 35.26438971;

Sin35 = sin(Zrot);
Cos35 = cos(Zrot);
Tan35 = tan(Zrot);

M5 = 5.5;                     //Hole Diameter
HoleRes = 24;                 //Resolution of small Holes
sin60 = 0.866025;
cos60 = 0.5;

explode = 0.0;   // set > 0.0 to push the parts apart (***Not implemented yet)

//These 2 variables are the same for any of the 2020, 2040, 2060 or 2080 extrusions
Car_OriginOffset_Y = 12;        //Origin Offset of Carriages from Centerline of Vertical Extrusion
CarHorOff = 24;      //Offset from Center line of Vertical Aluminums to Centerline of carriage arm connector
CarVerOff = 76.36 + (Frame_Top_Ht - 40);       //Offset from Top of Frame to Centerline of carriage arm connector
//echo("CarVerOff = ", CarVerOff);
Ef_Off = 37;            //horizontal distance from center to pivot

Eff_Half = Eff_Ht / 2;

//Calculate total Width of Verticals so we know which vertex to use
Alum_VertTopWid = Alum_VertWid * Alum_VertQty + Alum_VertGap;
echo("Alum_VertTopWid = ", Alum_VertTopWid);
//distance from center to center of Vertical extrusion & also origin of Vertex Plastic Part
//This is the Delta Radius
frame_r = ((Frame_Ext_Len / 2) + Vertex_X_offset) / sin60;
echo("frame_r = ",frame_r);
//*********************************************************
//*** Calculations for Tetrahedron at top of Delta Printer
//*********************************************************
T_Vertex_Rad = frame_r;
T_ApexTop_Ht = 25;            //Height of Apex Part
T_Z_Offset = 1.0;                 //1mm offset above Vertex connection
echo("T_Vertex_Rad = ",T_Vertex_Rad);


T_Z_Ht = Sin35 * EMT_Rad;            //6.93mm
//echo("T_Z_Ht = ",T_Z_Ht);

T_Y_Offset = (T_Z_Ht - T_Z_Offset) * Tan35;
//echo("T_Y_Offset = ",T_Y_Offset);

Tetra_Ht = T_Vertex_Rad /  Tan35;         //458.891mm


T_Apex_Z = Tetra_Ht - T_ApexTop_Ht + 2;     //I needed to add 2mm to come out correct
//echo("T_Apex_Z = ",T_Apex_Z);
T_PipeBot_SubLen = (T_Z_Ht + T_Z_Offset) / Cos35;     //9.71mm
T_PipeTop_SubLen = EMT_Rad /  Tan35;        //16.97mm
//Length of Pipe along Center line from Base to apex point
T_CL_Pipe_Len = T_Vertex_Rad / Sin35;       //562.025mm
T_Pipe_Len = T_CL_Pipe_Len - T_PipeBot_SubLen - (T_PipeTop_SubLen / 4); 

//Actual length of pipe we need to subtract,
//since we are not cutting pipe to match angle of tetrahedron
//This formula seems to work
//548.072mm
echo("*********************************************");
echo(" Printer Height with Tetrahedron attached = ",Frame_Ext_Ht+Tetra_Ht);
echo(" Tetra Top Pipe_Length to Cut = ",T_Pipe_Len);
echo("*********************************************");

Z90 = 90 - Zrot;            //54.73561029
Z54 = Z90 + -90;
//*************************************************************
//*** End Calculations for Tetrahedron at top of Delta Printer
//*************************************************************
//15.23 is distance from Centerline of Vertical extrusion to outside edge of Plastic Vertex
Printer_Y = (frame_r * 2) + (15.23 * 2);
Printer_X = (Printer_Xadd * 2) + Frame_Ext_Len;       //Overall X Dimension of Printer
Print_Radius = frame_r - (Frame_Ext_Wid / 2);
Arm_HorDist = frame_r - Ef_Off - CarHorOff;
echo("****Arm_HorDist = ",Arm_HorDist);
Arm_Len = Arm_HorDist / sin(Delta_Ang_1st);         //Arm length based on Delta_Ang_1st
//echo("Arm_Len = ",Arm_Len);                //Display calculated length based on orginal Delta_Angle
//I had to use a temporary variable for Angle initially, since openscad does not seem to like me
//redefining that variable after it was used
//This allows user to change either the angle or the length of the arms
//=========================================
//=== Change Arm Length Variable Here =====
//=========================================
DELTA_DIAGONAL_ROD = Arm_Len;                   //Change this to what length you want
//DELTA_DIAGONAL_ROD = 440;                       //444mm (17.5") maximum size I have found
//DELTA_DIAGONAL_ROD = 250;
echo("DELTA_DIAGONAL_ROD = ",DELTA_DIAGONAL_ROD);
//Re calculate Delta Angle & Vertical distance in case Arm Length was changed
Delta_Ang = asin(Arm_HorDist / DELTA_DIAGONAL_ROD);
echo("Delta_Ang = ",Delta_Ang);
echo("6x Horizontal Electrical Metal Conduit = ",Frame_Ext_Len,"mm");
echo("3x Vertical Extrusions = ",Frame_Ext_Ht,"mm");
echo("3x Tetrahedron EMT = ",T_Pipe_Len,"mm");
Arm_VerDist = Arm_HorDist / tan(Delta_Ang);
RotRod = -Delta_Ang;
RotRod_Y = RotRod;
RotRod_X = RotRod;
RotRod_Z = RotRod;

Rod_X = 30.5;                     //X offset of diagonal Arms
Rod_Y = 37;                       //Y offset from Center of effector
Eff_Top_Offset = Frame_Ext_Ht - (Arm_VerDist + CarVerOff + Eff_Half);
Hot_End_Z = (Eff_Top_Offset + Eff_Ht) - HotEnd_Ht;
//echo("Frame_Ext_Ht",Frame_Ext_Ht);
//echo("Arm_VerDist",Arm_VerDist);
//echo("CarVerOff",CarVerOff);
//echo("Eff_Half",Eff_Half);
//echo("Eff_Top_Offset",Eff_Top_Offset);
//**Eff_Top_Offset is off


//echo("=========Hot_End_Z = ",Hot_End_Z);
//echo("Frame_Ext_Ht = ",Frame_Ext_Ht);
//echo("Arm_VerDist = ",Arm_VerDist);
//echo("CarVerOff = ",CarVerOff);
//echo("Eff_Half = ",Eff_Half);
//echo("Eff_Top_Offset = ",Eff_Top_Offset);
//echo("asin(.511) = ",asin(0.5115816007));
//echo("*********************************");
Glass_Ht = Frame_Motor_Ht + Alum_BaseThk + Glass_Z_Offset+3;
endstop_Ht = 55;                //Height of extrusion should be this number
carriage_length = 50.7/2;       //half Length of Carriage along the Z axis
calc_carriage_Ht = Frame_Ext_Ht - (Frame_Top_Ht - 40) - carriage_length - endstop_Ht+8;
echo("calc_carriage_Ht = ",calc_carriage_Ht);
//calc_carriage_Ht = 668.65 - 339.7;      //Original Height - build Height
calc_carriage_Z = calc_carriage_Ht;
calc_carriage_X = calc_carriage_Ht;
calc_carriage_Y = calc_carriage_Ht;

Calc_Endstop_z = Frame_Ext_Ht - endstop_Ht;


Frame_half = Frame_Ext_Len / 2;
echo("Frame_half = ", Frame_half);
Len=Frame_half+Vertex_X_offset;
//echo("Len = ",Len);

frame_top = Frame_Ext_Ht - 20 + explode; 

Len=Frame_half+Vertex_X_offset;
frame_r1 = Len / sin60;                 //Distance from Center to Center of Vertical Extrusions
//echo("frame_r1 = ",frame_r1);
Y_Vertex = frame_r1 / 2;                //Y offset from center to insert Vertices
//echo("Y_Vertex = ",Y_Vertex);
Alum_Y = Y_Vertex + Vertex_Y_offset;    //Y offset from center to insert horizontal extrusions
echo("Alum_Y = ",Alum_Y);
BedRad = Alum_Y - 10;
echo("BedRad = ",BedRad);
BedDia = BedRad * 2;                    //Diameter to inside edge of horizontal extrusions
Max_Rad = BedDia + 10;                  //Maximum Radius might be to outside edge of Horizontal Alum.
//echo("------------------------");
echo("***** BedDia = ",BedDia, "mm  ",BedDia/25.4,"inches");
//echo("------------------------");
//frame_color = [0.7,0.25,0.7,0.98];
frame_color = "Blue";
plate_color = [0.7,0.7,1.0,0.5];
rod_color=[0.1,0.1,0.1,0.88];
v_slot_color="silver";

Max_Z_Ht = Hot_End_Z - (Alum_BaseThk + Frame_Motor_Ht + Glass_Z_Offset + Glass_Thk);
echo("***** Max Build Height:",Max_Z_Ht,"mm assuming a narrow tower or cone shaped build.");
echo("***** Max Build Height in Inches: ",Max_Z_Ht / 25.4,"inches");
echo("Printer Width = ",Printer_X, "mm ", Printer_X / 25.4,"inches");
echo("Printer Depth = ",Printer_Y, "mm ", Printer_Y / 25.4,"inches");
echo("Printer Height = ",Frame_Ext_Ht, "mm ", Frame_Ext_Ht / 25.4,"inches");
module DrawHorizontalAlumFrame()
{
    V_Slot_H();
    rotate([0,0,120])
    V_Slot_H();
    rotate([0,0,-120])
    V_Slot_H();
}
module DrawHorBaseAlumFrame()
{
    V_Slot_H(Alum_BaseHorWid,Alum_BaseHor_Z);
    rotate([0,0,120])
    V_Slot_H(Alum_BaseHorWid,Alum_BaseHor_Z);
    rotate([0,0,-120])
    V_Slot_H(Alum_BaseHorWid,Alum_BaseHor_Z);
}
module DrawHorTopAlumFrame()
{
    if (Alum_TopHorWid == 24)
    {
        V_Slot_H(Alum_TopHorWid,Alum_TopHor_Z);
        rotate([0,0,120])
        V_Slot_H(Alum_TopHorWid,Alum_TopHor_Z);
        rotate([0,0,-120])
        V_Slot_H(Alum_TopHorWid,Alum_TopHor_Z);
    } else{
        V_Slot_H(Alum_TopHorWid,Alum_TopHor_Z);
        rotate([0,0,120])
        V_Slot_H(Alum_TopHorWid,Alum_TopHor_Z);
        rotate([0,0,-120])
        V_Slot_H(Alum_TopHorWid,Alum_TopHor_Z);
    }
}
module V_Slot_H(Htype = Alum_BaseHorWid,Z_Ht = Alum_BaseHor_Z)
{
    translate([0,-Alum_Y,Z_Ht])
    rotate([0,90,0])
    EMT34(Frame_Ext_Len);
}

module Vertex_Motor()
{
    import("VertexBot_2xEMTSideMount_H_2060V_rev43_repaired.stl", convexity=3);
}
module VertexTop(Ht_V=Frame_Top_Ht)
{
    translate([0,0,40+10])
    rotate([0,0,180])
    rotate([180,0,0])
    import("VertexTop_1xEMTAtTop_SideMount_2060V_NoEars_rev43_repaired.stl", convexity=3);
}
module EMT34(Ht_A=Frame_Ext_Len)
{
    color(v_slot_color)
    rotate([0,0,-90])
    difference()
    {
        cylinder(d=EMT_OD,h=Ht_A,,center=true,$fn=48);
        translate([0,0,-1])
        cylinder(d=EMT_ID,h=Ht_A + 2,center=true,$fn=48);
    }
}
module V_Slot_Vert(Vrot=0)
{
    translate([-10,0,0])               //Move additional 10mm to left for 2060 size
    V_Slot_20x60(Frame_Ext_Ht);        //Draw 1st Vertical Extrusion
}
module V_Slot_20x60(Ht_A=Frame_Ext_Len)
{
//This was traced from the V-Slot 20x60 & taking out the small details
    color(v_slot_color)
    rotate([0,0,-90])
    difference()
    {
        linear_extrude(height = Ht_A, center = false, convexity = 10)polygon(points = 
        [[-2.84,-8.2],[-5.5,-8.2],[-5.5,-6.56],[-2.84,-3.9],[2.84,-3.9],
        [5.5,-6.56],[5.5,-8.2],[2.84,-8.2],[4.64,-10],[8.5,-10],
        [10,-8.5],[10,-4.64],[8.2,-2.84],[8.2,-5.5],[6.56,-5.5],
        [3.9,-2.84],[3.9,2.84],[6.56,5.5],[8.2,5.5],[8.2,2.84],
        [10,4.64],[10,15.36],[8.2,17.16],[8.2,14.5],[6.56,14.5],
        [3.9,17.16],[3.9,22.84],[6.56,25.5],[8.2,25.5],[8.2,22.84],
        [10,24.64],[10,35.36],[8.2,37.16],[8.2,34.5],[6.56,34.5],
        [3.9,37.16],[3.9,42.84],[6.56,45.5],[8.2,45.5],[8.2,42.84],
        [10,44.64],[10,48.5],[8.5,50],[4.64,50],[2.84,48.2],
        [5.5,48.2],[5.5,46.56],[2.84,43.9],[-2.84,43.9],[-5.5,46.56],
        [-5.5,48.2],[-2.84,48.2],[-4.64,50],[-8.5,50],[-10,48.5],
        [-10,44.64],[-8.2,42.84],[-8.2,45.5],[-6.56,45.5],[-3.9,42.84],
        [-3.9,37.16],[-6.56,34.5],[-8.2,34.5],[-8.2,37.16],[-10,35.36],
        [-10,24.64],[-8.2,22.84],[-8.2,25.5],[-6.56,25.5],[-3.9,22.84],
        [-3.9,17.16],[-6.56,14.5],[-8.2,14.5],[-8.2,17.16],[-10,15.36],
        [-10,4.64],[-8.2,2.84],[-8.2,5.5],[-6.56,5.5],[-3.9,2.84],
        [-3.9,-2.84],[-6.56,-5.5],[-8.2,-5.5],[-8.2,-2.84],[-10,-4.64],
        [-10,-8.5],[-8.5,-10],[-4.64,-10]]);
//Cut opening between 20x20's
        translate([0,0,-1])
        linear_extrude(height = Ht_A+2, center = false, convexity = 10)polygon(points = 
        [[-8.2,7.3],[-6.24,7.3],[-2.84,3.9],[2.84,3.9],[6.24,7.3],
        [8.2,7.3],[8.2,12.7],[6.24,12.7],[2.84,16.1],[-2.84,16.1],
        [-6.24,12.7],[-8.2,12.7]]);
//Cut 2nd opening
        translate([0,0,-1])
        linear_extrude(height = Ht_A+2, center = false, convexity = 10)polygon(points = 
        [[-8.2,27.3],[-6.24,27.3],[-2.84,23.9],[2.84,23.9],[6.24,27.3],
        [8.2,27.3],[8.2,32.7],[6.24,32.7],[2.84,36.1],[-2.84,36.1],
        [-6.24,32.7],[-8.2,32.7]]);
        translate([0,0,-1])
        cylinder(d=M5,h=Ht_A+2,$fn=HoleRes);      //Drill M5 holes
        translate([0,20,-1])
        cylinder(d=M5,h=Ht_A+2,$fn=HoleRes);
        translate([0,40,-1])
        cylinder(d=M5,h=Ht_A+2,$fn=HoleRes);
    }
}
module GlassTab()
{
    difference()
    {
        union()
        {
            cylinder(d=25.4,h=3.6,$fn=80);
            translate([-12.7,12.7,0])
            cube([25.4,28.2,3.6]);
        }
        translate([0,0,-1])
        cylinder(d=3.45,h=5.6,$fn=HoleRes);
    }
}
module SpiralBedClamp()
{
    rotate([0,0,180])
    translate([0,0,7.5])
    rotate([180,0,0])
    difference()
    {
        union()
        {
            linear_extrude(height = 4, center = false, convexity = 10)polygon(points = 
            [[-2.1,-4.16],[-2.1,-10.34],[-2.01,-10.77],[-1.74,-11.12],[-1.35,-11.31],
            [-0.91,-11.33],[1.24,-10.72],[3.24,-9.77],[5.02,-8.5],[6.56,-6.96],
            [7.78,-5.2],[8.67,-3.26],[9.2,-1.23],[9.35,0.44],[9.34,1.28],
            [9.04,3.31],[8.54,4.86],[7.61,6.65],[6.38,8.22],[4.83,9.55],
            [3.14,10.51],[1.32,11.11],[-0.93,11.34],[-2.62,11.16],[-4.37,10.61],
            [-5.94,9.72],[-7.27,8.55],[-8.31,7.15],[-9,5.58],[-9.33,3.94],
            [-9.28,2.29],[-8.87,0.77],[-8.13,-0.62],[-7.1,-1.76],[-5.88,-2.58],
            [-4.51,-3.06],[-3.15,-3.17],[-2.72,-3.24],[-2.36,-3.49],[-2.2,-3.74]]);
            translate([0,0,4])
            linear_extrude(height = 3.5, center = false, convexity = 10)polygon(points = 
            [[-2.1,-2.64],[-2.1,-7.27],[-2.01,-7.68],[-1.77,-8.02],[-1.41,-8.22],
            [-0.99,-8.26],[0.44,-7.81],[2.03,-6.99],[3.1,-6.2],[4.04,-5.28],
            [4.95,-4.08],[5.57,-2.94],[6.01,-1.76],[6.2,-0.94],[6.32,-0.11],
            [6.34,0.51],[6.31,1.54],[6.09,2.74],[5.7,3.89],[5.09,5.02],
            [4.32,6.03],[3.54,6.77],[2.46,7.5],[1.17,8.05],[0.11,8.29],
            [-1.16,8.33],[-2.36,8.14],[-3.48,7.71],[-4.34,7.18],[-5.07,6.52],
            [-5.73,5.62],[-6.12,4.74],[-6.33,3.73],[-6.32,2.86],[-6.14,2.03],
            [-5.99,1.65],[-5.78,1.27],[-5.72,1],[-5.53,0.49],[-5.13,-0.22],
            [-4.58,-0.82],[-3.91,-1.29],[-3.16,-1.6],[-2.76,-1.7],[-2.52,-1.83],
            [-2.32,-2.02],[-2.18,-2.25],[-2.1,-2.64]]);
        }
        translate([-2.14,1.98,-1])
        cylinder(d=6,h=5,$fn=HoleRes);
        translate([-2.14,1.98,3])
        cylinder(d=3.5,h=6,$fn=HoleRes);
    }
}
module GlassTabs()
{
    color(frame_color)
    {
        translate([0,-Alum_Y,Alum_EMT_2X_Z+25.35])
        GlassTab();
        translate([0,-Alum_Y,Alum_EMT_2X_Z+25.35+ 3.6])
        SpiralBedClamp();
    }
}
module EffVertHoles()
{
    for(i=[0:11])
    {
        rotate([0,0,i*30])
        translate([27,0,0])
        cylinder(d=3.1,h=20,$fn=HoleRes);
    }
    for(i=[0:2])
    {
        rotate([0,0,i*120])
        translate([30,-37,5.04])
        rotate([0,-90,0])
        cylinder(d=3,h=60,$fn=HoleRes);
    }
}
module Effector()
{
    difference()
    {
        linear_extrude(height = 11, center = false, convexity = 10)polygon(points = 
        [[-27.5,-21.07],[-27.5,-42.54],[-12.5,-42.54],
        [-12.5,-34.53],[12.5,-34.53],[12.5,-42.54],
        [27.5,-42.54],[27.5,-21.07],[32,-13.28],
        [50.59,-2.54],[43.09,10.45],[36,6.35],
        [23.5,28],[30.59,32.1],[23.09,45.09],
        [4.8,34.53],[-4.8,34.53],[-23.09,45.09],
        [-30.59,32.1],[-23.5,28],[-36,6.35],
        [-43.09,10.45],[-50.59,-2.54],[-32,-13.28]]);
        translate([0,0,-1])
        cylinder(d=42,h=13,$fn=132);
        EffVertHoles();
    }
}
module CarriageFront()
{
    color("Orange")
    rotate([0,0,180])
    import("carriage_20x60_Rev20_repaired.stl", convexity=3);
}
module CarriageBack()
{
    color("Orange")
    import("BackPlate_20x60_Rev20_repaired.stl", convexity=3);
}
echo("Alum_EMT_2X_Z = ",Alum_EMT_2X_Z);
module EMT_GlassBracket()
{
//    translate([0,-Alum_Y,Frame_Motor_Ht + Alum_BaseThk])
    translate([0,-Alum_Y,Alum_EMT_2X_Z])
    rotate([0,0,90])
    rotate([90,0,0])
    color("Orange")
    import("EMT_GlassBracket_12mmHt_rev8_repaired.stl", convexity=3);
}
module Carriage()
{
    rotate([90,0,0])
    CarriageFront();
    rotate([-90,0,0])
    translate([0,0,25])
    CarriageBack();
}
module EndStop()
{
    translate([0,frame_r1-12,Calc_Endstop_z])    //22.35
    rotate([90,0,0])
    difference()
    {
        linear_extrude(height = 9, center = false, convexity = 10)polygon(points = 
        [[-8.5,0],[8.5,0],[8.5,7.5],
        [7.5,7.5],[7.5,15],[-7.5,15],
        [-7.5,7.5],[-8.5,7.5]]);
        translate([-4.75,5.5,-1])
        cylinder(d=2.5,h=20,$fn=HoleRes);
        translate([4.75,5.5,-1])
        cylinder(d=2.5,h=20,$fn=HoleRes);
        translate([0,10.5,-1])
        cylinder(d=3.45,h=20,$fn=HoleRes);
    }
}
//======================================================================
//=== This is where Vertices & Aluminum of the Delta is put together ===
//======================================================================
module DrawFrame()
{
//Draw Bottom Vertex corners
    color(frame_color)
    {
        for (z = [-120:120:120])        
        {
            rotate([0,0,z])
            translate([0,frame_r,Alum_BaseThk])
            rotate([0,0,180])
            Vertex_Motor(Frame_Motor_Ht);

        }
//Draw Top Vertex corners
        for (z = [-120:120:120])        
        {
            rotate([0,0,z])
            translate([0,frame_r,Frame_Ext_Ht-Frame_Top_Ht-6])
            //rotate([0,0,180])
            color("Blue")
            VertexTop();
            //VertexTop(Frame_Top_Ht);                 //Draw 1,2,3 top Vertex
        }
    }
//Draw the Bottom Horizontal Aluminum Extrusion(s)
    DrawHorBaseAlumFrame();

            translate([0,0,40])
            DrawHorBaseAlumFrame();

//Draw the Top Horizontal Aluminum Extrusion(s)
    translate([0,0,Frame_Ext_Ht - 14])
    DrawHorTopAlumFrame();          //Draw Top Aluminum Frame
    if (Alum_TopQty == 2)
    {  
        translate([0,0,Frame_Ext_Ht - Alum_TopHorWid - Alum_TopHorWid - Alum_TopGap])
        DrawHorTopAlumFrame();          //Draw Top Aluminum Frame
    }

//Draw Vertical Aluminum extrusions
    translate([-Len,-Y_Vertex,0])
    rotate([0,0,-60])
    translate([-10,0,0])
    V_Slot_Vert(-60);
    //V_Slot_20x40(Frame_Ext_Ht);        //Draw 1st Vertical Extrusion
    
    translate([Len,-Y_Vertex,0])
    rotate([0,0,60])
    translate([-10,0,0])
    V_Slot_Vert(60);
    //V_Slot_20x40(Frame_Ext_Ht);        //Draw 2nd Vertical Extrusion
    
    translate([0,frame_r,0])
    rotate([0,0,0])
    translate([-10,0,0])
    V_Slot_Vert(0);
    //V_Slot_20x40(Frame_Ext_Ht);        //Draw 3rd Vertical Extrusion
}
//    if (Alum_VertTopWid == 24)
//    {
//        V_Slot_20x40(Frame_Ext_Ht);        //Draw 1st Vertical Extrusion
//        translate([-2,-27.125,0])               //Move additional 10mm to left for 2060 size
//        EMT34(Frame_Ext_Ht);        //Draw 1st Vertical Extrusion
//        translate([22,-27.125,0])               //Move additional 10mm to left for 2060 size
//        EMT34(Frame_Ext_Ht);        //Draw 1st Vertical Extrusion
//    }
module DrawEndStops()
{
    EndStop();
    rotate([0,0,120])
    EndStop();
    rotate([0,0,-120])
    EndStop();
}
module Diag_Rod_Y()
{
    translate([0,0,0])
    rotate([RotRod_Y,0,0])                        //Rotate Rod Horizontal 1st
    color(rod_color)
    cylinder(r=Rod_Rad,h=DELTA_DIAGONAL_ROD);
}
module Diag_Rod_X()
{
    translate([0,0,0])
    rotate([RotRod_X,0,0])                        //Rotate Rod Horizontal 1st
    color(rod_color)
    cylinder(r=Rod_Rad,h=DELTA_DIAGONAL_ROD);
}
module Diag_Rod_Z()
{
    translate([0,0,0])
    rotate([RotRod_Z,0,0])                        //Rotate Rod Horizontal 1st
    color(rod_color)
    cylinder(r=Rod_Rad,h=DELTA_DIAGONAL_ROD);
}
module Car_Y()
{
    translate([0,frame_r1-12,calc_carriage_Y])
    Carriage();
    
    //rotate([RotRod_Y,0,0])
    {
        translate([Rod_X,Rod_Y,Eff_Top_Offset + Eff_Half])
        Diag_Rod_Y();
    
        translate([-Rod_X,Rod_Y,Eff_Top_Offset + Eff_Half])
        Diag_Rod_Y();
    }
}
module Car_X()
{
    rotate([0,0,120])
    translate([0,frame_r1-12,calc_carriage_X])

    Carriage();
    
    //rotate([RotRod_Y,0,0])
    {
        rotate(120)
        translate([Rod_X,Rod_Y,Eff_Top_Offset + Eff_Half])
        Diag_Rod_X();

        rotate(120)
        translate([-Rod_X,Rod_Y,Eff_Top_Offset + Eff_Half])
        Diag_Rod_X();
    }
}
module Car_Z()
{
    rotate([0,0,-120])
    translate([0,frame_r1-12,calc_carriage_Z])

    Carriage();
    
    //rotate([RotRod_Y,0,0])
    {
        rotate(-120)
        translate([Rod_X,Rod_Y,Eff_Top_Offset + Eff_Half])
        Diag_Rod_Z();

        rotate(-120)
        translate([-Rod_X,Rod_Y,Eff_Top_Offset + Eff_Half])
        Diag_Rod_Z();
    }
}
module DrawFinal()
{
    DrawFrame();                            //Draw Alum. Extusions & 6 Vertices
    color("red")
    DrawEndStops();
    Car_Y();                            //Draw Carriage & Arm on Y Tower
    Car_X();                            //Draw Carriage & Arm on X Tower
    Car_Z();                            //Draw Carriage & Arm on Z Tower

    translate([0,0,Eff_Top_Offset])       //Not sure why it was 10.54mm off
    rotate([0,0,60])
    color(frame_color) //x-tower upper endstop
    Effector();
//hotend  HotEnd_Ht = 45;
    translate([0,0,((Eff_Top_Offset + Eff_Ht) - HotEnd_Ht)])
    color("cyan")
    cylinder(r=10,h=HotEnd_Ht,center=false);
//Fill Center hole of Effector
    translate([0,0,Eff_Top_Offset])
    color("red")
    cylinder(h=Eff_Ht,r=21,center=false);

    GlassTabs();
    rotate([0,0,120])
    GlassTabs();
    rotate([0,0,-120])
    GlassTabs();

    EMT_GlassBracket();
    rotate([0,0,120])
    EMT_GlassBracket();
    rotate([0,0,-120])
    EMT_GlassBracket();
//Draw Glass Build Plate
    translate([0,0,Glass_Ht])
    color(plate_color)
    cylinder(r=BedRad+5,h=Glass_Thk);             //Draw Build plate cylinder
}
//***************************************
//*** Draw the Tetrahedron at the Top ***
//***************************************
//T_Vertex_Rad = T_Vertex_Dia / 2;


module TetraCorner()
{
    rotate([0,0,180])
        color("orange")
    translate([0,0,25])
    rotate([180,0,0])
    import("TetraBot_EMT_TopOfVertex_rev11_repaired.stl", convexity=3);
}
module TetraTop()
{
    rotate([0,0,180])
        color("orange")
    import("parametric_Tetrahedron34_EMT_Apex_Rev1.stl", convexity=3);
}
module Pipe()
{
    color(v_slot_color)
    difference()
    {
        cylinder(d=EMT_OD,h=T_Pipe_Len,$fn=48);
        translate([0,0,-1])
        cylinder(d=EMT_ID,h=T_Pipe_Len+2,$fn=48);
    }
}
module DrawCorner()
{

    translate([0,-T_Vertex_Rad,0])
    {
        translate([0,-T_Y_Offset,T_Z_Ht+1])
        rotate([Z54,0,0])
        Pipe();
        TetraCorner();       //Draw 1st vertex at correct location and Angle
    }
}
//Draw the Top Tetrahedron
translate([0,0,Frame_Ext_Ht+12])
rotate([0,0,180])
{
    DrawCorner();           //Draw 1st Vertex
    rotate([0,0,120])
    DrawCorner();           //Draw 2nd Vertex
    rotate([0,0,-120])
    DrawCorner();           //Draw 3rd Vertex
    
    translate([0,0,T_Apex_Z])
    TetraTop();             //Draw the Apex
}
//*************************
//*** Draw Name Bracket ***
//*************************
TetraRot = 23.8666;         //Rotation of Tetra Angle
module EmmettName()
{
    rotate([90,0,0])
    color("blue")
    import("EMT_Name_Rev2_repaired.stl", convexity=3);
}
module NameBracket()
{
    color("orange")
    import("EMT_Emmett_NameBracket_AsDesigned_rev1_repaired.stl", convexity=3);
}
module DrawNameBracket()
{
    rotate([-TetraRot,0,0])
    translate([72,0,0])
    {
        rotate([0,150,0])
        NameBracket();
    
        translate([-144,0,0])
        rotate([0,-150,0])
        mirror([1,0,0])
        NameBracket();
    
        translate([-132,8,-61.5])
        EmmettName();
    }
}
translate([0,-42,Frame_Ext_Ht+Tetra_Ht-100])
DrawNameBracket();
DrawFinal();