//Program to calculate the length of pipe you want to use for Top Tetrahedron
//1/5/2016      By: David Bunch
//
$vpt=[-12.6,145,97];
$vpr =[62,0,31.3];
$vpd =1800;
//Comment examples show calcs for 24mm OD pipe & 648.97 Dia
//This design uses 500mm horizontal lengths of EMT
EMT_OD = 24;               //24 for 3/4" EMT, 17.8 for 1/2" EMT
EMT_ID = 21;
EMT_Rad = EMT_OD / 2;
T_Vertex_Dia = 648.97;        //Diameter that 3 Vertices are located on
T_Vertex_Rad = T_Vertex_Dia / 2;
T_ApexTop_Ht = 25;            //Height of Apex Part
T_Z_Offset = 1.0;                 //1mm offset above Vertex connection
echo("T_Vertex_Rad = ",T_Vertex_Rad);
Zrot = 35.26438971;

Sin35 = sin(Zrot);
Cos35 = cos(Zrot);
Tan35 = tan(Zrot);

T_Z_Ht = Sin35 * EMT_Rad;            //6.93mm
echo("T_Z_Ht = ",T_Z_Ht);

T_Y_Offset = (T_Z_Ht - T_Z_Offset) * Tan35;
echo("T_Y_Offset = ",T_Y_Offset);

T_PipeBot_SubLen = (T_Z_Ht + T_Z_Offset) / Cos35;     //9.71mm
echo("T_PipeBot_SubLen = ",T_PipeBot_SubLen);

T_PipeTop_SubLen = EMT_Rad /  Tan35;        //16.97mm
echo("T_PipeTop_SubLen = ",T_PipeTop_SubLen);

Tetra_Ht = T_Vertex_Rad /  Tan35;         //458.891mm
echo("Tetra_Ht = ",Tetra_Ht);

T_Apex_Z = Tetra_Ht - T_ApexTop_Ht + 2;     //I needed to add 2mm to come out correct
echo("T_Apex_Z = ",T_Apex_Z);

//Length of Pipe along Center line from Base to apex point
T_CL_Pipe_Len = T_Vertex_Rad / Sin35;       //562.025mm
echo("T_CL_Pipe_Len = ",T_CL_Pipe_Len);

//Actual length of pipe we need to subtract,
//since we are not cutting pipe to match angle of tetrahedron
//This formula seems to work
T_Pipe_Len = T_CL_Pipe_Len - T_PipeBot_SubLen - (T_PipeTop_SubLen / 4); //548.072mm
echo("*****************************");
echo("** Pipe_Length to Cut = ",T_Pipe_Len);
echo("*****************************");

Z90 = 90 - Zrot;            //54.73561029
Z54 = Z90 + -90;

$fn=76;                     //Resolution of EMT
module TetraCorner()
{
    rotate([0,0,180])
    color("blue",.5)
    translate([0,0,25])
    rotate([180,0,0])
    import("TetraBot_EMT_TopOfVertex_rev11_repaired.stl", convexity=3);
}
module TetraTop()
{
    rotate([0,0,180])
    color("blue",.5)
    import("parametric_Tetrahedron34_EMT_Apex_Rev1.stl", convexity=3);
}
module Pipe()
{
    difference()
    {
        cylinder(d=EMT_OD,h=T_Pipe_Len);
        translate([0,0,-1])
        cylinder(d=EMT_ID,h=T_Pipe_Len+2);
    }
}
module DrawCorner()
{
    translate([0,-T_Vertex_Rad,0])
    {
        translate([0,-T_Y_Offset,T_Z_Ht+1])
        rotate([Z54,0,0])
        Pipe();
        TetraCorner();       //Draw 1st vertex at correct location and Angle
    }
}
DrawCorner();           //Draw 1st Vertex
rotate([0,0,120])
DrawCorner();           //Draw 2nd Vertex
rotate([0,0,-120])
DrawCorner();           //Draw 3rd Vertex

translate([0,0,T_Apex_Z])
TetraTop();             //Draw the Apex